@@ -38,6 +38,10 @@ _seq_acaml_re = re.compile(
     f'^sequence{_acaml_re.pattern}',
     re.IGNORECASE,
 )
+_samp_acaml_re = re.compile(
+    f'^sample{_acaml_re.pattern}',
+    re.IGNORECASE,
+)
 # prefix regex to deal with irritating prefixed tree names
 _prefix_re = re.compile('(?P<prefix>.+)ACAML')
 # regex to extract timezone from Agilent date time string
@@ -313,12 +317,17 @@ class HPLCSampleInfo(object):
                 acaml = pathlib.Path(acaml)
             if os.path.isdir(acaml):  # not a acaml file
                 seq_files = [filename for filename in os.listdir(acaml) if _seq_acaml_re.match(filename) is not None]
-                if len(seq_files) != 1:
+                samp_files = [filename for filename in os.listdir(acaml) if _samp_acaml_re.match(filename) is not None]
+                if len(seq_files) == 1:
+                    acaml = acaml / seq_files[0]
+                elif len(samp_files) == 1:
+                    acaml = acaml / samp_files[0]
+                else:
                     raise IOError(
                         f'{"Multiple" if len(seq_files) > 1 else "No"}'
-                        f' sequence.acam_ files were found in the directory "{acaml}". Please refine your search.'
+                        f' sequence.acam_ or sample.acaml files were found in the directory "{acaml}". '
+                        f'Please refine your search.'
                     )
-                acaml = acaml / seq_files[0]
             else:
                 if _acaml_re.search(acaml.suffix) is None:
                     # todo consider trying to parse anyway
